pyramid_resourceful
+++++++++++++++++++

``pyramid_resourceful`` is a somewhat-opinionated toolkit for building
resourceful Web services and applications on top of the Pyramid Web
framework.

Take a look in the ``examples`` directory for self-contained, runnable
examples.

See https://pyramid-resourceful.readthedocs.io/ for detailed documentation
of interfaces, APIs, and usage.

License
=======

This package is provided under the MIT license. See the ``LICENSE`` file
for details.
